@@ -61,7 +61,7 @@ ods_bluez_cancellable_free (OdsBluezCancellable *cb_data)
 
 static gboolean
 client_socket_connect_cb (GIOChannel *io_channel, GIOCondition cond,
-							OdsBluezCancellable *cb_data)
+                          OdsBluezCancellable *cb_data)
 {
 	OdsBluezFunc	cb = cb_data->cb;
 	gint			fd;
@@ -102,77 +102,77 @@ static void
 rfcomm_connect (OdsBluezCancellable *cb_data, gint channel)
 {
 	OdsBluezFunc		cb = cb_data->cb;
-    GError				*error = NULL;
-    struct sockaddr_rc	addr;
-    int					fd = -1;
-    GIOChannel			*io_channel = NULL;
+	GError				*error = NULL;
+	struct sockaddr_rc	addr;
+	int					fd = -1;
+	GIOChannel			*io_channel = NULL;
 
-    /* Create socket and start connecting */
-    fd = socket (AF_BLUETOOTH, SOCK_STREAM, BTPROTO_RFCOMM);
-    if (fd < 0) {
+	/* Create socket and start connecting */
+	fd = socket (AF_BLUETOOTH, SOCK_STREAM, BTPROTO_RFCOMM);
+	if (fd < 0) {
 		g_set_error (&error, ODS_ERROR, ODS_ERROR_CONNECTION_ATTEMPT_FAILED,
-	    	    		"Could not create socket");
+		             "Could not create socket");
 		goto err;
-    }
+	}
 
-    memset (&addr, 0, sizeof(addr));
-    /* source address */
-    addr.rc_family  = AF_BLUETOOTH;
-    bacpy (&addr.rc_bdaddr, &cb_data->source_address);
+	memset (&addr, 0, sizeof(addr));
+	/* source address */
+	addr.rc_family  = AF_BLUETOOTH;
+	bacpy (&addr.rc_bdaddr, &cb_data->source_address);
 
-    if (bind (fd, (struct sockaddr *) &addr, sizeof (addr)) < 0) {
-	    g_set_error (&error, ODS_ERROR,
-	    				ODS_ERROR_CONNECTION_ATTEMPT_FAILED,
-	    				"Binding to local device failed (errno: %d)", errno);
-	    goto err;
-    }
+	if (bind (fd, (struct sockaddr *) &addr, sizeof (addr)) < 0) {
+		g_set_error (&error, ODS_ERROR,
+		             ODS_ERROR_CONNECTION_ATTEMPT_FAILED,
+		             "Binding to local device failed (errno: %d)", errno);
+		goto err;
+	}
 
-    memset (&addr, 0, sizeof(addr));
-    /* destination address */
-    addr.rc_family  = AF_BLUETOOTH;
-    addr.rc_channel = channel;
-    bacpy (&addr.rc_bdaddr, &cb_data->target_address);
+	memset (&addr, 0, sizeof(addr));
+	/* destination address */
+	addr.rc_family  = AF_BLUETOOTH;
+	addr.rc_channel = channel;
+	bacpy (&addr.rc_bdaddr, &cb_data->target_address);
 
-    /* Use non-blocking connect */
-    fcntl (fd, F_SETFL, O_NONBLOCK);
-    io_channel = g_io_channel_unix_new (fd);
+	/* Use non-blocking connect */
+	fcntl (fd, F_SETFL, O_NONBLOCK);
+	io_channel = g_io_channel_unix_new (fd);
 
-    if (connect (fd, (struct sockaddr *) &addr, sizeof(addr)) < 0) {
+	if (connect (fd, (struct sockaddr *) &addr, sizeof(addr)) < 0) {
 		/* BlueZ returns EAGAIN eventhough it should return EINPROGRESS */
 		if (!(errno == EAGAIN || errno == EINPROGRESS)) {
-		    g_set_error (&error, ODS_ERROR,
-		    				ODS_ERROR_CONNECTION_ATTEMPT_FAILED,
-		    				"Connecting to remote device failed");
-		    goto err;
+			g_set_error (&error, ODS_ERROR,
+			             ODS_ERROR_CONNECTION_ATTEMPT_FAILED,
+			             "Connecting to remote device failed");
+			goto err;
 		}
 
 		g_message ("Connect in progress");
 		cb_data->io_watch = g_io_add_watch (io_channel,
-								G_IO_OUT | G_IO_ERR | G_IO_NVAL | G_IO_HUP,
-								(GIOFunc) client_socket_connect_cb, cb_data);
+		                                    G_IO_OUT | G_IO_ERR | G_IO_NVAL | G_IO_HUP,
+		                                    (GIOFunc) client_socket_connect_cb, cb_data);
 		cb_data->fd = fd;
-    } else {
+	} else {
 		/* Connect succeeded with first try */
-    	g_message ("Connect on first try");
+		g_message ("Connect on first try");
 		client_socket_connect_cb (io_channel, G_IO_OUT, cb_data);
-    }
-    g_io_channel_unref (io_channel);
-    return;
+	}
+	g_io_channel_unref (io_channel);
+	return;
 
 err:
 	if (io_channel)
 		g_io_channel_unref (io_channel);
-    if (fd >= 0)
-    	close (fd);
-    cb (-1, cb_data->channel, cb_data->imagingdata, error, cb_data->cb_data);
-    ods_bluez_cancellable_free (cb_data);
-    g_clear_error (&error);
+	if (fd >= 0)
+		close (fd);
+	cb (-1, cb_data->channel, cb_data->imagingdata, error, cb_data->cb_data);
+	ods_bluez_cancellable_free (cb_data);
+	g_clear_error (&error);
 }
 
 
 static void
 sdp_get_channel (sdp_record_t *sdp_record,
-					OdsBluezCancellable *cb_data)
+                 OdsBluezCancellable *cb_data)
 {
 	OdsBluezFunc		cb = cb_data->cb;
 	GError				*error = NULL;
@@ -183,7 +183,7 @@ sdp_get_channel (sdp_record_t *sdp_record,
 	/* get channel for this service */
 	if (sdp_get_access_protos (sdp_record, &protos) != 0) {
 		g_set_error (&error, ODS_ERROR, ODS_ERROR_FAILED,
-						"Could not get service channel");
+		             "Could not get service channel");
 		goto err;
 	}
 
@@ -198,30 +198,30 @@ sdp_get_channel (sdp_record_t *sdp_record,
 		sdpdata = sdp_data_get (sdp_record, SDP_ATTR_SUPPORTED_CAPABILITIES);
 		cb_data->imagingdata->supp_capabilities = sdpdata->val.uint8;
 		g_message ("supp_capabilities: %d", cb_data->imagingdata->supp_capabilities);
-		
+
 		sdpdata = sdp_data_get (sdp_record, SDP_ATTR_SUPPORTED_FEATURES);
 		cb_data->imagingdata->supp_features = sdpdata->val.uint16;
 		g_message ("supp_features: %d", cb_data->imagingdata->supp_features);
-		
+
 		sdpdata = sdp_data_get (sdp_record, SDP_ATTR_SUPPORTED_FUNCTIONS);
 		cb_data->imagingdata->supp_functions = sdpdata->val.uint32;
 		g_message ("supp_funcs: %d", cb_data->imagingdata->supp_functions);
-		
+
 		sdpdata = sdp_data_get (sdp_record, SDP_ATTR_TOTAL_IMAGING_DATA_CAPACITY);
 		cb_data->imagingdata->data_capacity = sdpdata->val.uint64;
 		g_message ("data_cap: %" G_GUINT64_FORMAT, cb_data->imagingdata->data_capacity);
-		
+
 		if (!(cb_data->imaging_feature & cb_data->imagingdata->supp_features)) {
 			g_set_error (&error, ODS_ERROR, ODS_ERROR_NOT_SUPPORTED,
-							"Selected imaging feature not supported");
+			             "Selected imaging feature not supported");
 			goto err;
 		}
 	}
 
- 	if (protos) {
+	if (protos) {
 		sdp_list_foreach (protos, (sdp_list_func_t)sdp_list_free, 0);
 		sdp_list_free (protos, 0);
- 	}
+	}
 
 	rfcomm_connect (cb_data, channel);
 	return;
@@ -233,8 +233,8 @@ err:
 }
 
 static void sdp_search_completed_cb (uint8_t type, uint16_t status,
-										uint8_t *rsp, size_t size,
-										void *user_data)
+                                     uint8_t *rsp, size_t size,
+                                     void *user_data)
 {
 	OdsBluezCancellable *ctxt = user_data;
 	OdsBluezFunc cb = ctxt->cb;
@@ -246,7 +246,7 @@ static void sdp_search_completed_cb (uint8_t type, uint16_t status,
 
 	if (status || type != SDP_SVC_SEARCH_ATTR_RSP) {
 		g_set_error (&error, ODS_ERROR, ODS_ERROR_CONNECTION_ATTEMPT_FAILED,
-						"Service search failed");
+		             "Service search failed");
 		goto done;
 	}
 
@@ -261,7 +261,7 @@ static void sdp_search_completed_cb (uint8_t type, uint16_t status,
 
 	if (!scanned) {
 		g_set_error (&error, ODS_ERROR, ODS_ERROR_CONNECTION_ATTEMPT_FAILED,
-						"Service search failed");
+		             "Service search failed");
 		goto done;
 	}
 
@@ -294,36 +294,37 @@ static void sdp_search_completed_cb (uint8_t type, uint16_t status,
 
 		recs = sdp_list_append(recs, rec);
 	} while (scanned < size && bytesleft > 0);
-	
+
 	if (sdp_list_len (recs) == 0) {
 		g_message ("no SDP records found");
 		if (!memcmp (&ctxt->uuid.value.uuid128, OBEX_NOKIAFTP_UUID,
-					sizeof(uint128_t))) {
+		             sizeof(uint128_t))) {
 			g_message ("Using standard OBEX FTP uuid");
 			sdp_uuid16_create (&ctxt->uuid, OBEX_FILETRANS_SVCLASS_ID);
 			if (!sdp_initiate_search (ctxt))
 				g_set_error (&error, ODS_ERROR, ODS_ERROR_CONNECTION_ATTEMPT_FAILED,
-								"Service search failed");
+				             "Service search failed");
 		} else {
 			g_set_error (&error, ODS_ERROR, ODS_ERROR_NOT_SUPPORTED,
-							"Service not supported by remote device");
-		}		
+			             "Service not supported by remote device");
+		}
 	} else {
+		sdp_record_print (recs->data);
 		sdp_get_channel (recs->data, ctxt);
 	}
-	
+
 done:
 	if (error) {
 		cb (-1, ctxt->channel, ctxt->imagingdata, error, ctxt->cb_data);
 		ods_bluez_cancellable_free (ctxt);
-		g_clear_error (&error);	
+		g_clear_error (&error);
 	}
 	if (recs)
 		sdp_list_free(recs, (sdp_free_func_t) sdp_record_free);
 }
 
 static gboolean sdp_search_process_cb (GIOChannel *chan,
-										GIOCondition cond, void *user_data)
+                                       GIOCondition cond, void *user_data)
 {
 	OdsBluezCancellable *ctxt = user_data;
 	OdsBluezFunc cb = ctxt->cb;
@@ -332,10 +333,10 @@ static gboolean sdp_search_process_cb (GIOChannel *chan,
 	g_message ("SDP search process");
 	if (cond & (G_IO_ERR | G_IO_HUP | G_IO_NVAL)) {
 		g_set_error (&error, ODS_ERROR, ODS_ERROR_CONNECTION_ATTEMPT_FAILED,
-						"Service search failed");
+		             "Service search failed");
 		cb (-1, ctxt->channel, ctxt->imagingdata, error, ctxt->cb_data);
 		ods_bluez_cancellable_free (ctxt);
-		g_clear_error (&error);	
+		g_clear_error (&error);
 
 		return FALSE;
 	}
@@ -353,15 +354,16 @@ static gboolean sdp_initiate_search (OdsBluezCancellable *ctxt)
 	sdp_list_t *search, *attrids;
 	uint32_t range = 0x0000ffff;
 	gboolean ret = TRUE;
-	
+
 	/* Set callback responsible for calling sdp_process */
 	ctxt->io_watch = g_io_add_watch(ctxt->io_channel,
-									G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_NVAL,
-									sdp_search_process_cb, ctxt);
+	                                G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_NVAL,
+	                                sdp_search_process_cb, ctxt);
 	search = sdp_list_append(NULL, &ctxt->uuid);
 	attrids = sdp_list_append(NULL, &range);
 	if (sdp_service_search_attr_async(ctxt->session,
-				search, SDP_ATTR_REQ_RANGE, attrids) < 0) {
+	                                  search, SDP_ATTR_REQ_RANGE, attrids) < 0) {
+		ods_safe_gsource_remove (&ctxt->io_watch);
 		ret = FALSE;
 	}
 
@@ -371,15 +373,15 @@ static gboolean sdp_initiate_search (OdsBluezCancellable *ctxt)
 }
 
 static gboolean sdp_connect_watch (GIOChannel *chan, GIOCondition cond,
-									gpointer user_data)
+                                   gpointer user_data)
 {
 	OdsBluezCancellable *ctxt = user_data;
-	
+
 	socklen_t len;
 	int sk, err = 0;
 	GError *error = NULL;
 	OdsBluezFunc cb = ctxt->cb;
-	
+
 	sk = g_io_channel_unix_get_fd(chan);
 
 	len = sizeof(err);
@@ -395,13 +397,13 @@ static gboolean sdp_connect_watch (GIOChannel *chan, GIOCondition cond,
 
 	if (!sdp_initiate_search (ctxt))
 		goto failed;
-	
+
 	return FALSE;
 
 failed:
 	g_set_error (&error, ODS_ERROR, ODS_ERROR_CONNECTION_ATTEMPT_FAILED,
-					"Service search failed (%s)",
-					err ? strerror(err) : "Could not start search");
+	             "Service search failed (%s)",
+	             err ? strerror(err) : "Could not start search");
 	cb (-1, ctxt->channel, ctxt->imagingdata, error, ctxt->cb_data);
 	ods_bluez_cancellable_free (ctxt);
 	g_clear_error (&error);
@@ -411,12 +413,12 @@ failed:
 
 OdsBluezCancellable*
 ods_bluez_get_client_socket (const bdaddr_t *dst,
-								const bdaddr_t *src,
-								const uuid_t *uuid,
-								guint imaging_feature,
-								gint channel,
-								OdsBluezFunc func,
-								gpointer data)
+                             const bdaddr_t *src,
+                             const uuid_t *uuid,
+                             guint imaging_feature,
+                             gint channel,
+                             OdsBluezFunc func,
+                             gpointer data)
 {
 	OdsBluezCancellable *cb_data;
 
@@ -428,7 +430,7 @@ ods_bluez_get_client_socket (const bdaddr_t *dst,
 	cb_data->imaging_feature = imaging_feature;
 	cb_data->channel = -1;
 	cb_data->fd = -1;
-	
+
 	/* Discover channel for needed service only if we don't know it yet */
 	if (channel == 0) {
 		cb_data->session = sdp_connect (src, dst, SDP_NON_BLOCKING);
@@ -436,13 +438,13 @@ ods_bluez_get_client_socket (const bdaddr_t *dst,
 			ods_bluez_cancellable_free (cb_data);
 			return NULL;
 		}
-	
+
 		cb_data->io_channel = g_io_channel_unix_new (
-									sdp_get_socket (cb_data->session));
+		                          sdp_get_socket (cb_data->session));
 		cb_data->io_watch = g_io_add_watch (cb_data->io_channel,
-									G_IO_OUT | G_IO_HUP | G_IO_ERR | G_IO_NVAL,
-									sdp_connect_watch, cb_data);
-		
+		                                    G_IO_OUT | G_IO_HUP | G_IO_ERR | G_IO_NVAL,
+		                                    sdp_connect_watch, cb_data);
+
 		/* From Johan Hedberg:
 		 *
 		 * some Nokia Symbian phones have two OBEX FTP services: one
@@ -453,19 +455,19 @@ ods_bluez_get_client_socket (const bdaddr_t *dst,
 		 */
 		/* if FTP was requested, use NOKIAFTP instead,
 		 * if it isn't found we retreat to FTP in get_remote_service_handles_cb */
-		if (uuid->value.uuid16 == OBEX_FILETRANS_SVCLASS_ID || 
-				!memcmp(&uuid->value.uuid128, OBEX_FTP_UUID, sizeof(uint128_t))) {
+		if (uuid->value.uuid16 == OBEX_FILETRANS_SVCLASS_ID ||
+		        !memcmp(&uuid->value.uuid128, OBEX_FTP_UUID, sizeof(uint128_t))) {
 			g_message ("FTP uuid selected, first checking for Nokia OBEX PC Suite Services uuid");
 			sdp_uuid128_create (&cb_data->uuid, OBEX_NOKIAFTP_UUID);
 		} else
 			memcpy (&cb_data->uuid, uuid, sizeof (uuid_t));
-		
+
 	} else {
 		/* skip SDP requests and connect to specified RFCOMM channel */
 		cb_data->channel = channel;
 		rfcomm_connect (cb_data, channel);
 	}
-	
+
 	return cb_data;
 }
 
@@ -474,16 +476,16 @@ ods_bluez_cancel_get_client_socket (OdsBluezCancellable *cancel)
 {
 	OdsBluezFunc	cb = cancel->cb;
 	GError			*error = NULL;
-	
+
 	/* cancel connecting */
 	if (cancel->io_watch > 0) {
 		if (cancel->fd >= 0)
 			close (cancel->fd);
-		g_source_remove (cancel->io_watch);
+		ods_safe_gsource_remove (&cancel->io_watch);
 	}
 	/* callback */
 	g_set_error (&error, ODS_ERROR, ODS_ERROR_CANCELLED,
-					"Cancelled by DBus client");
+	             "Cancelled by DBus client");
 	cb (-1, cancel->channel, cancel->imagingdata, error, cancel->cb_data);
 	g_clear_error (&error);
 	ods_bluez_cancellable_free (cancel);
@@ -525,14 +527,14 @@ sdp_session_get (const gchar *device, gboolean create_new)
 	SdpSessionRecords *recs;
 	sdp_session_t *session;
 	bdaddr_t src;
-	
+
 	if (sdp_session_list &&
-			(recs = g_hash_table_lookup (sdp_session_list, device))) {
+	        (recs = g_hash_table_lookup (sdp_session_list, device))) {
 		return recs->session;
 	}
 	if (!create_new)
 		return NULL;
-	
+
 	str2ba (device, &src);
 	session = sdp_connect (&src, BDADDR_LOCAL, SDP_RETRY_IF_BUSY);
 	if (!session) {
@@ -546,10 +548,10 @@ static void
 sdp_session_list_add (const gchar *device, sdp_session_t *session)
 {
 	SdpSessionRecords *recs;
-	
+
 	if (!sdp_session_list) {
 		sdp_session_list = g_hash_table_new_full (g_str_hash, g_str_equal,
-													g_free, g_free);
+		                   g_free, g_free);
 	}
 	if (!(recs = g_hash_table_lookup (sdp_session_list, device))) {
 		recs = g_new0 (SdpSessionRecords, 1);
@@ -565,7 +567,7 @@ static void
 sdp_session_list_remove (const gchar *device)
 {
 	SdpSessionRecords *recs;
-	
+
 	if (!sdp_session_list)
 		return;
 	if (!(recs = g_hash_table_lookup (sdp_session_list, device)))
@@ -588,20 +590,20 @@ add_bin_service_record (const gchar *device, sdp_record_t *rec)
 	session = sdp_session_get (device, TRUE);
 	if (!session)
 		return 0;
-	
+
 	ret = sdp_device_record_register (session, &src, rec, 0);
 	if (ret < 0) {
-	    g_warning("Failed to register sdp record, ret: %i", ret);
-	    return 0;
+		g_warning("Failed to register sdp record, ret: %i", ret);
+		return 0;
 	}
-	
+
 	sdp_session_list_add (device, session);
 	return rec->handle;
 }
 
 guint32
 ods_bluez_add_service_record (const gchar *device, gint service,
-								ImagingSdpData *imagingdata)
+                              ImagingSdpData *imagingdata)
 {
 	guint32 ret;
 	/* vars that differ according to service */
@@ -629,7 +631,7 @@ ods_bluez_add_service_record (const gchar *device, gint service,
 
 	switch (service) {
 		case ODS_SERVICE_OPP:
-	
+
 			chan = ODS_OPP_RFCOMM_CHANNEL;
 			svclass_id_ = OBEX_OBJPUSH_SVCLASS_ID;
 			profile_id_ = OBEX_OBJPUSH_PROFILE_ID;
@@ -691,8 +693,8 @@ ods_bluez_add_service_record (const gchar *device, gint service,
 
 	if (service == ODS_SERVICE_OPP) {
 		for (i = 0; i < sizeof(formats); i++) {
-		    dtds[i] = &dtd;
-		    values[i] = &formats[i];
+			dtds[i] = &dtd;
+			values[i] = &formats[i];
 		}
 		sflist = sdp_seq_alloc (dtds, values, sizeof(formats));
 		sdp_attr_add (&rec, SDP_ATTR_SUPPORTED_FORMATS_LIST, sflist);
@@ -740,7 +742,7 @@ ods_bluez_remove_service_record (const gchar *device, guint32 record_handle)
 		g_warning ("Couldn't get SDP session");
 		return;
 	}
-	
+
 	ret = sdp_device_record_unregister_binary (session,	&src, record_handle);
 	if (ret)
 		g_warning ("Failed to unregister service record");
