@@ -26,6 +26,6 @@
 
 void ods_log_init (const char *ident, gboolean enable_syslog, gboolean enable_debug);
 void ods_log_finalize ();
-void ods_log_obex (int evt, int cmd, int rsp);
+void ods_log_obex (const char *prefix, int evt, int cmd, int rsp);
 
 #endif /*__ODS_LOGGING_H_*/
