@@ -1,5 +1,8 @@
 #include "config.h"
 
+#ifdef USE_USB
+
+#include <glib.h>
 #include <stdio.h>		/* perror */
 #include <errno.h>		/* errno and EADDRNOTAVAIL */
 #include <string.h>
@@ -7,9 +10,6 @@
 
 #include "ods-usb.h"
 
-#ifdef USE_USB
-#define DEBUG(x...) 
-
 struct ods_usb_intf_transport_t {
 	struct ods_usb_intf_transport_t *prev, *next;	/* Next and previous interfaces in the list */
 	struct usb_device *device;		/* USB device that has the interface */
@@ -17,8 +17,8 @@ struct ods_usb_intf_transport_t {
 	int configuration_description;		/* Configuration string descriptor number */
 	int control_interface;			/* OBEX master interface */
 	int control_setting;			/* OBEX master interface setting */
-	int control_interface_description;	/* OBEX master interface string descriptor number 
-						 * If non-zero, use usb_get_string_simple() from 
+	int control_interface_description;	/* OBEX master interface string descriptor number
+						 * If non-zero, use usb_get_string_simple() from
 						 * libusb to retrieve human-readable description
 						 */
 	unsigned char *extra_descriptors;		/* Extra master interface descriptors */
@@ -88,9 +88,9 @@ static void find_eps(struct ods_usb_intf_transport_t *intf, struct usb_interface
 		ep0 = data_intf.endpoint;
 		ep1 = data_intf.endpoint + 1;
 		if ((ep0->bEndpointAddress & USB_ENDPOINT_IN) &&
-		    ((ep0->bmAttributes & USB_ENDPOINT_TYPE_MASK) == USB_ENDPOINT_TYPE_BULK) &&
-		    !(ep1->bEndpointAddress & USB_ENDPOINT_IN) &&
-		    ((ep1->bmAttributes & USB_ENDPOINT_TYPE_MASK) == USB_ENDPOINT_TYPE_BULK)) {
+		        ((ep0->bmAttributes & USB_ENDPOINT_TYPE_MASK) == USB_ENDPOINT_TYPE_BULK) &&
+		        !(ep1->bEndpointAddress & USB_ENDPOINT_IN) &&
+		        ((ep1->bmAttributes & USB_ENDPOINT_TYPE_MASK) == USB_ENDPOINT_TYPE_BULK)) {
 			*found_active = 1;
 			intf->data_active_setting = data_intf.bAlternateSetting;
 			intf->data_interface_active_description = data_intf.iInterface;
@@ -98,9 +98,9 @@ static void find_eps(struct ods_usb_intf_transport_t *intf, struct usb_interface
 			intf->data_endpoint_write = ep1->bEndpointAddress;
 		}
 		if (!(ep0->bEndpointAddress & USB_ENDPOINT_IN) &&
-		    ((ep0->bmAttributes & USB_ENDPOINT_TYPE_MASK) == USB_ENDPOINT_TYPE_BULK) &&
-		    (ep1->bEndpointAddress & USB_ENDPOINT_IN) &&
-		    ((ep1->bmAttributes & USB_ENDPOINT_TYPE_MASK) == USB_ENDPOINT_TYPE_BULK)) {
+		        ((ep0->bmAttributes & USB_ENDPOINT_TYPE_MASK) == USB_ENDPOINT_TYPE_BULK) &&
+		        (ep1->bEndpointAddress & USB_ENDPOINT_IN) &&
+		        ((ep1->bmAttributes & USB_ENDPOINT_TYPE_MASK) == USB_ENDPOINT_TYPE_BULK)) {
 			*found_active = 1;
 			intf->data_active_setting = data_intf.bAlternateSetting;
 			intf->data_interface_active_description = data_intf.iInterface;
@@ -126,30 +126,30 @@ static int find_obex_data_interface(unsigned char *buffer, int buflen, struct us
 	int found_idle = 0;
 
 	if (!buffer) {
-		DEBUG(2,"Weird descriptor references");
+		g_debug("Weird descriptor references");
 		return -EINVAL;
 	}
 
 	while (buflen > 0) {
 		if (buffer [1] != USB_DT_CS_INTERFACE) {
-			DEBUG(2,"skipping garbage");
+			g_debug("skipping garbage");
 			goto next_desc;
 		}
 		switch (buffer [2]) {
-		case CDC_UNION_TYPE: /* we've found it */
-			if (union_header) {
-				DEBUG(2,"More than one union descriptor, skiping ...");
-				goto next_desc;
-			}
-			union_header = (struct cdc_union_desc *)buffer;
-			break;
-		case CDC_OBEX_TYPE: /* maybe check version */
-		case CDC_OBEX_SERVICE_ID_TYPE: /* This one is handled later */
-		case CDC_HEADER_TYPE:
-			break; /* for now we ignore it */
-		default:
-			DEBUG(2, "Ignoring extra header, type %d, length %d", buffer[2], buffer[0]);
-			break;
+			case CDC_UNION_TYPE: /* we've found it */
+				if (union_header) {
+					g_debug("More than one union descriptor, skiping ...");
+					goto next_desc;
+				}
+				union_header = (struct cdc_union_desc *)buffer;
+				break;
+			case CDC_OBEX_TYPE: /* maybe check version */
+			case CDC_OBEX_SERVICE_ID_TYPE: /* This one is handled later */
+			case CDC_HEADER_TYPE:
+				break; /* for now we ignore it */
+			default:
+				g_debug("Ignoring extra header, type %d, length %d", buffer[2], buffer[0]);
+				break;
 		}
 next_desc:
 		buflen -= buffer[0];
@@ -157,7 +157,7 @@ next_desc:
 	}
 
 	if (!union_header) {
-		DEBUG(2,"No union descriptor, giving up\n");
+		g_debug("No union descriptor, giving up");
 		return -ENODEV;
 	}
 	/* Found the slave interface, now find active/idle settings and endpoints */
@@ -173,11 +173,11 @@ next_desc:
 		}
 	}
 	if (!found_idle) {
-		DEBUG(2,"No idle setting\n");
+		g_debug("No idle setting");
 		return -ENODEV;
 	}
 	if (!found_active) {
-		DEBUG(2,"No active setting\n");
+		g_debug("No active setting");
 		return -ENODEV;
 	}
 
@@ -203,14 +203,13 @@ static int get_intf_string(struct usb_dev_handle *usb_handle, char **string, int
  * Helper function to usbobex_find_interfaces
  */
 static struct ods_usb_intf_transport_t *check_intf(struct usb_device *dev,
-					int c, int i, int a,
-					char *bus, char *device,
-					struct ods_usb_intf_transport_t *current)
-{
+			        int c, int i, int a,
+			        char *bus, char *device,
+			        struct ods_usb_intf_transport_t *current) {
 	struct ods_usb_intf_transport_t *next = NULL;
 
 	if ((dev->config[c].interface[i].altsetting[a].bInterfaceClass == USB_CDC_CLASS)
-	    && (dev->config[c].interface[i].altsetting[a].bInterfaceSubClass == USB_CDC_OBEX_SUBCLASS)) {
+	        && (dev->config[c].interface[i].altsetting[a].bInterfaceSubClass == USB_CDC_OBEX_SUBCLASS)) {
 		int err;
 		unsigned char *buffer = dev->config[c].interface[i].altsetting[a].extra;
 		int buflen = dev->config[c].interface[i].altsetting[a].extralen;
@@ -261,39 +260,39 @@ static struct ods_usb_intf_transport_t *check_intf(struct usb_device *dev,
 static void find_obex_service_descriptor(unsigned char *buffer, int buflen, ods_usb_intf_service_t **service)
 {
 	if (!buffer) {
-		DEBUG(2, "Weird descriptor references");
+		g_debug("Weird descriptor references");
 		return ;
 	}
 	while (buflen > 0) {
 		if (buffer[1] != USB_DT_CS_INTERFACE) {
-			DEBUG(2, "skipping garbage");
+			g_debug("skipping garbage");
 			goto next_desc;
 		}
 		switch (buffer[2]) {
-		case CDC_OBEX_SERVICE_ID_TYPE: /* we've found it */
-			if (buflen < 22) /* Check descriptor size */
-				DEBUG(2, "Invalid service id descriptor");
-			else if (*service == NULL) {
-				*service = malloc(sizeof(ods_usb_intf_service_t));
-				if (*service != NULL) {
-					const guint8 default_uuid[16] = WMC_DEFAULT_OBEX_SERVER_UUID;
-					(*service)->role = buffer[3];
-					memcpy((*service)->uuid, buffer+4, 16);
-					(*service)->version = (buffer[20]<<8)|(buffer[21]);
-					if (memcmp((*service)->uuid, default_uuid, 16) == 0 )
-						(*service)->is_default_uuid = 1;
-					else
-						(*service)->is_default_uuid = 0;
+			case CDC_OBEX_SERVICE_ID_TYPE: /* we've found it */
+				if (buflen < 22) /* Check descriptor size */
+					g_debug("Invalid service id descriptor");
+				else if (*service == NULL) {
+					*service = malloc(sizeof(ods_usb_intf_service_t));
+					if (*service != NULL) {
+						const guint8 default_uuid[16] = WMC_DEFAULT_OBEX_SERVER_UUID;
+						(*service)->role = buffer[3];
+						memcpy((*service)->uuid, buffer+4, 16);
+						(*service)->version = (buffer[20]<<8)|(buffer[21]);
+						if (memcmp((*service)->uuid, default_uuid, 16) == 0 )
+							(*service)->is_default_uuid = 1;
+						else
+							(*service)->is_default_uuid = 0;
+					}
 				}
-			}
-			break;
-		case CDC_OBEX_TYPE: /* maybe check version */
-		case CDC_UNION_TYPE:
-		case CDC_HEADER_TYPE:
-			break;
-		default:
-			DEBUG(2, "Ignoring extra header, type %d, length %d", buffer[2], buffer[0]);
-			break;
+				break;
+			case CDC_OBEX_TYPE: /* maybe check version */
+			case CDC_UNION_TYPE:
+			case CDC_HEADER_TYPE:
+				break;
+			default:
+				g_debug("Ignoring extra header, type %d, length %d", buffer[2], buffer[0]);
+				break;
 		}
 next_desc:
 		buflen -= buffer[0];
@@ -353,23 +352,23 @@ GList *ods_usbobex_find_interfaces(void)
 		item = g_new0 (ods_usb_info, 1);
 
 		get_intf_string(usb_handle, &item->manufacturer,
-				current->device->descriptor.iManufacturer);
+		                current->device->descriptor.iManufacturer);
 		get_intf_string(usb_handle, &item->product,
-				current->device->descriptor.iProduct);
+		                current->device->descriptor.iProduct);
 		get_intf_string(usb_handle, &item->serial,
-				current->device->descriptor.iSerialNumber);
+		                current->device->descriptor.iSerialNumber);
 		get_intf_string(usb_handle, &item->configuration,
-				current->configuration_description);
+		                current->configuration_description);
 		get_intf_string(usb_handle, &item->control_interface,
-				current->control_interface_description);
+		                current->control_interface_description);
 		get_intf_string(usb_handle, &item->data_interface_idle,
-				current->data_interface_idle_description);
+		                current->data_interface_idle_description);
 		get_intf_string(usb_handle, &item->data_interface_active,
-				current->data_interface_active_description);
+		                current->data_interface_active_description);
 		item->path = current->path;
 		find_obex_service_descriptor(current->extra_descriptors,
-					current->extra_descriptors_len,
-					&item->service);
+		                             current->extra_descriptors_len,
+		                             &item->service);
 		usb_close(usb_handle);
 		current = current->next;
 		list = g_list_prepend (list, item);
