@@ -8,7 +8,7 @@ from os.path import basename,splitext
 from signal import *
 from time import ctime
 
-bt_address = '00:16:20:46:4B:82'
+bt_address = '00:12:EE:7C:30:D4'
 #bt_address = '00:01:E3:54:D0:87'
 folder_to_go_to = 'Pictures'
 folder_to_create = 'Nonsense'
@@ -24,14 +24,12 @@ class Tester:
         manager_obj = self.bus.get_object('org.openobex', '/org/openobex')
         self.manager = dbus.Interface(manager_obj, 'org.openobex.Manager')
         
-        print self.manager.GetUsbInterfacesNum()
-        exit()
-        session_path = self.manager.CreateBluetoothSession(bt_address, '00:00:00:00:00:00', 'ftp')
-        print 'Session object: ', session_path
-        session_obj = self.bus.get_object('org.openobex', session_path)
+        self.session_path = self.manager.CreateBluetoothSession(bt_address, '00:00:00:00:00:00', 'ftp')
+        print 'Session object: ', self.session_path
+        session_obj = self.bus.get_object('org.openobex', self.session_path)
         self.session = dbus.Interface(session_obj, 'org.openobex.Session')
 
-        self.session.connect_to_signal('Connected', self.connected_cb)
+        self.manager.connect_to_signal('SessionConnected', self.connected_cb)
         self.session.connect_to_signal('Disconnected', self.disconnected_cb)
         self.session.connect_to_signal('Closed', self.closed_cb)
         self.session.connect_to_signal('Cancelled', self.cancelled_cb)
@@ -43,9 +41,10 @@ class Tester:
         self.main_loop = gobject.MainLoop()
         self.main_loop.run()
     
-    def connected_cb(self):
-        print 'Connected'
-        self.run()
+    def connected_cb(self, session_path):
+        if session_path == self.session_path:
+            print 'Connected'
+            self.run()
         
     def disconnected_cb(self):
         print 'Disconnected'
@@ -60,16 +59,21 @@ class Tester:
         self.run()
 
     def transfer_started_cb(self, filename, local_path, total_bytes):
+        if self.exec_iter == 3:
+            self.call_method('Cancel')
+            return
+        
         print 'Transfer started (%s, %s, %d)' % (filename, local_path, total_bytes)
         self.total_bytes = total_bytes
         transfer_info = self.call_method('GetTransferInfo')
         print '-- Size           = %s' % transfer_info['Size']
         print '-- RemoteFilename = %s' % transfer_info['RemoteFilename']
         print '-- LocalPath      = %s' % transfer_info['LocalPath']
-        print '-- Time           = ', transfer_info['Time']
+        if 'Time' in transfer_info:
+            print '-- Time           = ', transfer_info['Time']
     
     def transfer_progress_cb(self, bytes_transferred):
-        if self.total_bytes != -1:
+        if self.total_bytes != 0:
             print 'Progress: %d %%' % int(float(bytes_transferred)/self.total_bytes*100)
         else:
             print 'Progress'
@@ -100,8 +104,6 @@ class Tester:
         
     def run(self):
         if self.exec_iter == 0:
-            print self.call_method('IsConnected')
-            
             print self.call_method('RetrieveFolderListing')
             print self.call_method('GetCurrentPath')
             
@@ -131,7 +133,6 @@ class Tester:
             self.call_method('DeleteRemoteFile', basename(file_to_send))
             
             self.call_method('SendFile', file_to_send)
-            self.call_method('Cancel')
         elif self.exec_iter == 3:
             self.call_method('ChangeCurrentFolderToRoot')
             print self.call_method('GetCurrentPath')
